@@ -68,7 +68,6 @@ try:
   # Import pyca/cryptography routines needed to generate and load cryptographic
   # keys in PEM format.
   from cryptography.hazmat.primitives import serialization
-  from cryptography.hazmat.backends.interfaces import PEMSerializationBackend
   from cryptography.hazmat.primitives.serialization import load_pem_private_key
   from cryptography.hazmat.backends import default_backend
 
@@ -455,11 +454,6 @@ def verify_rsa_signature(signature, signature_scheme, public_key, data):
   # What about 'data'?
   securesystemslib.formats.DATA_SCHEMA.check_match(data)
 
-  # Verify whether the private key of 'public_key' produced 'signature'.
-  # Before returning the 'valid_signature' Boolean result, ensure 'RSASSA-PSS'
-  # was used as the signature scheme.
-  valid_signature = False
-
   # Verify the RSASSA-PSS signature with pyca/cryptography.
   try:
     public_key_object = serialization.load_pem_public_key(
@@ -486,7 +480,7 @@ def verify_rsa_signature(signature, signature_scheme, public_key, data):
       # This is a defensive check check..
       else:  # pragma: no cover
         raise securesystemslib.exceptions.UnsupportedAlgorithmError('Unsupported'
-            ' signature scheme is specified: ' + repr(scheme))
+            ' signature scheme is specified: ' + repr(signature_scheme))
 
       return True
 
@@ -991,8 +985,7 @@ def _encrypt(key_data, derived_key_information):
   # a decryption operation.
   symmetric_key = derived_key_information['derived_key']
   salt = derived_key_information['salt']
-  hmac_object = \
-    cryptography.hazmat.primitives.hmac.HMAC(symmetric_key, hashes.SHA256(),
+  hmac_object = hmac.HMAC(symmetric_key, hashes.SHA256(),
         backend=default_backend())
   hmac_object.update(ciphertext)
   hmac_value = binascii.hexlify(hmac_object.finalize())
@@ -1031,7 +1024,7 @@ def _decrypt(file_contents, password):
   # separating.  Raise 'securesystemslib.exceptions.CryptoError', if
   # 'file_contents' does not contains the expected data layout.
   try:
-    salt, iterations, hmac, iv, ciphertext = \
+    salt, iterations, read_hmac, iv, ciphertext = \
       file_contents.split(_ENCRYPTION_DELIMITER)
 
   except ValueError:
@@ -1054,14 +1047,13 @@ def _decrypt(file_contents, password):
   # See the encryption routine for why we use the encrypt-then-MAC approach.
   # The decryption routine may verify a ciphertext without having to perform
   # a decryption operation.
-  generated_hmac_object = \
-    cryptography.hazmat.primitives.hmac.HMAC(symmetric_key, hashes.SHA256(),
+  generated_hmac_object = hmac.HMAC(symmetric_key, hashes.SHA256(),
         backend=default_backend())
   generated_hmac_object.update(ciphertext)
   generated_hmac = binascii.hexlify(generated_hmac_object.finalize())
 
 
-  if not securesystemslib.util.digests_are_equal(generated_hmac.decode(), hmac):
+  if not securesystemslib.util.digests_are_equal(generated_hmac.decode(), read_hmac):
     raise securesystemslib.exceptions.CryptoError('Decryption failed.')
 
   # Construct a Cipher object, with the key and iv.
